OC.L10N.register(
    "core",
    {
    "Please select a file." : "Vælg fil",
    "File is too big" : "Filen er for stor",
    "Invalid file provided" : "Der er angivet en ugyldig fil",
    "No image or file provided" : "Ingen fil eller billede givet",
    "Unknown filetype" : "Ukendt filtype",
    "Invalid image" : "Ugyldigt billede",
    "An error occurred. Please contact your admin." : "Der opstod et problem. Kontakt venligst administratoren.",
    "No temporary profile picture available, try again" : "Intet midlertidigt profilbillede tilgængeligt, prøv igen",
    "No crop data provided" : "Ingen beskæringsdata give",
    "No valid crop data provided" : "Der er ikke angivet gyldige data om beskæring",
    "Crop is not square" : "Beskæringen er ikke kvadratisk",
    "%s password changed successfully" : "App %s succesfuldt opdateret",
    "%s password reset" : "%s adgangskode nulstillet",
    "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst systemadministratoren.",
    "Upload only" : "Upload kun",
    "Preparing update" : "Forbereder opdatering",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Reparationsadvarsel:",
    "Repair error: " : "Reparationsfejl:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Brug kommandolinje-updateren, da automatisk opdatering er slået fra i config.php",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrollere tabel %s",
    "Turned on maintenance mode" : "Startede vedligeholdelsestilstand",
    "Turned off maintenance mode" : "standsede vedligeholdelsestilstand",
    "Maintenance mode is kept active" : "Vedligeholdelsestilstanden holdes kørende",
    "Updating database schema" : "Opdaterer database schema",
    "Updated database" : "Opdaterede database",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
    "Checked database schema update" : "Tjekket database schema opdatering",
    "Checking updates of apps" : "Tjekker opdatering af apps",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tjekker om database schema'et for %s kan opdateres (dette kan tage lang tid afhængig af databasens størrelse)",
    "Checked database schema update for apps" : "Tjekkede databaseskemaets opdatering for apps",
    "Updated \"%s\" to %s" : "Opdaterede \"%s\" til %s",
    "Set log level to debug" : "Sæt logningsniveau til fejlfinding",
    "Reset log level" : "Nulstil logningsniveau",
    "Starting code integrity check" : "Begynder tjek af kodeintegritet",
    "Finished code integrity check" : "Fuldførte tjek af kodeintegritet",
    "%s (3rdparty)" : "%s (3rdparty)",
    "%s (incompatible)" : "%s (inkombatible)",
    "Following apps have been disabled: %s" : "Følgende apps er blevet deaktiveret: %s",
    "Already up to date" : "Allerede opdateret",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Marts",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Der var problemer med integritetskontrollen af koden. Mere information...</a>",
    "Settings" : "Indstillinger",
    "Problem loading page, reloading in 5 seconds" : "Problem med indlæsning af side, genindlæser om 5 sekunder",
    "Saving..." : "Gemmer...",
    "Dismiss" : "Afvis",
    "seconds ago" : "sekunder siden",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linket til at nulstille dit kodeord er blevet sendt til din e-post: hvis du ikke modtager den inden for en rimelig tid, så tjek dine spam/junk-mapper.<br> Hvis det ikke er der, så spørg din lokale administrator.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dine filer er krypterede. Hvis du ikke har aktiveret gendannelsesnøglen kan du ikke få dine data tilbage efter at du har ændret adgangskode.<br />Hvis du ikke er sikker på, hvad du skal gøre så kontakt din administrator før du fortsætter.<br />Vil du fortsætte?",
    "I know what I'm doing" : "Jeg ved, hvad jeg har gang i",
    "Password can not be changed. Please contact your administrator." : "Adgangskoden kunne ikke ændres. Kontakt venligst din administrator.",
    "No" : "Nej",
    "Yes" : "Ja",
    "Choose" : "Vælg",
    "Error loading file picker template: {error}" : "Fejl ved indlæsning af filvælger skabelon: {error}",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Fejl ved indlæsning af besked skabelon: {error}",
    "read-only" : "skrivebeskyttet",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nye filer",
    "Already existing files" : "Allerede eksisterende filer",
    "Which files do you want to keep?" : "Hvilke filer ønsker du at beholde?",
    "If you select both versions, the copied file will have a number added to its name." : "Hvis du vælger begge versioner, vil den kopierede fil få tilføjet et nummer til sit navn.",
    "Cancel" : "Annuller",
    "Continue" : "Videre",
    "(all selected)" : "(alle valgt)",
    "({count} selected)" : "({count} valgt)",
    "Error loading file exists template" : "Fejl ved inlæsning af; fil eksistere skabelon",
    "Very weak password" : "Meget svagt kodeord",
    "Weak password" : "Svagt kodeord",
    "So-so password" : "Jævnt kodeord",
    "Good password" : "Godt kodeord",
    "Strong password" : "Stærkt kodeord",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat korrekt op til at tillade filsynkronisering, fordi WebDAV-grænsefladen ser ud til at være i stykker.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Din web-server er ikke konfigureret korrekt til at opløse \"{url}\". Yderligere information kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Denne ownCloud-server har ikke en fungerende forbindelse til internettet. Det betyder, at visse funktioner som montering af eksterne drev, oplysninger om opdatering eller installation af applikationer fra tredjepart ikke fungerer. Det vil sandsynligvis heller ikke være muligt at tilgå filer fra eksterne drev eller afsendelse af e-mail med notifikationer virker sandsynligvis heller ikke. Vi opfordrer til at etablere forbindelse til internettet for denne server, såfremt du ønsker samtlige funktioner.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Der er ikke konfigureret noget hukommelsesmellemlager. For at forbedre din ydelse bør du om muligt konfigurere en mamcache. Yderligere information findes i <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentationen</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom kan ikke læses af PHP, hvilket stærkt frarådes af sikkerhedsgrunde. Yderligere information kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du kører i øjeblikket med PHP {version}. Vi anbefaler dig at opgradere din PHP version for at få glæde af <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">ydelses- og sikkerhedsopdateringer udgivet af the PHP Group</a> så snart din dintribution understøtter dem.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Konfigurationen af reverse proxy-headere er ikke korrekt eller du tilgår ownCloud fra en betroet proxy. Hvis du ikke tilgår ownCloud fra en betroet proxy, så er dette et sikkerhedsproblem og kan tillade en angriber af forfalske deres IP-adresse som synlig for ownCloud. Yderligere information kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dokumentation</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er konfigureret som et distribueret mellemlager, men det forkerte PHP-modul \"memcache\" er installeret. \\OC\\Memcache\\Memcached understøtter kun \"memcached\" og ikke \"memcache\". Se <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached-wikien om begge moduler</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Nogle filer har ikke bestået integritetskontrollen. Yderligere information om hvordan man løser dette problem kan findes i vores <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">dodumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste over ugyldige filer...</a> / <a href=\"{rescanEndpoint}\">Scan igen…</a>)",
    "Error occurred while checking server setup" : "Der opstod fejl under tjek af serveropsætningen",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Din data mappe og dine filer er muligvis tilgængelige fra internettet. Filen .htaccess fungerer ikke. Vi anbefaler på det kraftigste, at du konfigurerer din webserver således at datamappen ikke længere er tilgængelig, eller at du flytter datamappen uden for webserverens dokumentrod.  ",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP-hovedet \"{header}\" er ikke konfigureret til at være lig med \"{expected}\". Dette er en potentiel sikkerhedsrisiko, og vi anbefaler at du justerer denne indstilling.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "HTTP headeren \"Strict-Transport-Security\" er ikke konfigureret til mindst \"{seconds}\" sekunder. For bedre sikkerhed anbefaler vi at aktivere HSTS som beskrevet i vores <a href=\"{docUrl}\" rel=\"noreferrer\">sikkerhedstips</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du tilgår dette sted gennem HTTP. Vi anbefaler kraftigt at du konfigurerer din server, så der kræves brug af HTTPS i stedet for, som foreskrevet i vores <a href=\"{docUrl}\">sikkerhedstips</a>.",
    "Shared" : "Delt",
    "Shared with {recipients}" : "Delt med {recipients}",
    "Error" : "Fejl",
    "Error while sharing" : "Fejl under deling",
    "Error while unsharing" : "Fejl under annullering af deling",
    "The public link will expire no later than {days} days after it is created" : "Det offentlige link udløber senest {days} dage efter det blev oprettet",
    "Expiration" : "Udløb",
    "Expiration date is required" : "Udløbsdato er påkrævet",
    "Delete {link}" : "Slet {link}",
    "Remove link" : "Fjern link",
    "Link" : "Link",
    "Create public link" : "opret offentligt link",
    "Edit" : "Redigér",
    "Remove" : "Fjern",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Social share" : "Social deling",
    "There are currently no link shares, you can create one" : "Der er på nuværende tidspunkt ingen liks delt med dig, du kan oprettet et",
    "Anyone with the link has access to the file/folder" : "Alle med linket har adgang til filen/mappen",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet!",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Choose a password" : "Vælg et kodeord",
    "Password required" : "Kodeord påkrævet",
    "Link name" : "Linknavn",
    "Name" : "Navn",
    "Filename" : "Filnavn",
    "Password" : "Adgangskode",
    "Edit link share: {name}" : "Rediger linkdeling: {name}",
    "Create link share: {name}" : "Opret linkdeling: {name}",
    "Share" : "Del",
    "Save" : "Gem",
    "Remove password" : "Fjern kodeord",
    "Share to Twitter. Opens in a new window." : "Del med Twitter. Åbner i et nyt vindue.",
    "Share to Facebook. Opens in a new window." : "Del med Facebook. Åbner i et nyt vindue.",
    "Share to Diaspora. Opens in a new window." : "Del med Diaspora Åbner i et nyt vindue.",
    "Share to Google+. Opens in a new window." : "Del med Google+. Åbner i et nyt vindue.",
    "Share via email. Opens your mail client." : "Del via email. Åbner din mail klient.",
    "Email link to person" : "E-mail link til person",
    "Send link via email" : "Send link via e-mail",
    "Sending" : "Sender",
    "Shared with you and the group {group} by {owner}" : "Delt med dig og gruppen {group} af {owner}",
    "Shared with you by {owner}" : "Delt med dig af {owner}",
    "group" : "gruppe",
    "notify by email" : "Giv besked med mail",
    "Unshare" : "Fjern deling",
    "can share" : "kan dele",
    "can edit" : "kan redigere",
    "create" : "opret",
    "change" : "tilpas",
    "delete" : "slet",
    "access control" : "Adgangskontrol",
    "Could not unshare" : "Kunne ikke ophæve deling",
    "Share details could not be loaded for this item." : "Detaljer for deling kunne ikke indlæses for dette element.",
    "No users or groups found for {search}" : "Ingen brugere eller grupper fundet for {search}",
    "No users found for {search}" : "Ingen brugere fundet for {search}",
    "An error occurred. Please try again" : "Der opstor den fejl. Prøv igen",
    "User" : "Bruger",
    "Group" : "Gruppe",
    "User and Groups" : "Bruger og Grupper",
    "Public Links" : "Offentlige links",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Del med andre på ownCloud ved hjælp af syntaxen username@example.com/owncloud",
    "Share with users…" : "Del med brugere...",
    "Share with users, groups or remote users…" : "Del med brugere, grupper eller eksterne brugere...",
    "Share with users or groups…" : "Del med brugere eller grupper...",
    "Share with users or remote users…" : "Del med brugere eller eksterne brugere...",
    "Error removing share" : "Fejl ved fjernelse af deling",
    "Non-existing tag #{tag}" : "Ikke-eksisterende mærke #{tag}",
    "restricted" : "begrænset",
    "invisible" : "usynlig",
    "({scope})" : "({scope})",
    "Delete" : "Slet",
    "Rename" : "Omdøb",
    "Collaborative tags" : "Kollaborative tags",
    "The object type is not specified." : "Objekttypen er ikke angivet.",
    "Enter new" : "Indtast nyt",
    "Add" : "Tilføj",
    "Edit tags" : "Redigér mærker",
    "Error loading dialog template: {error}" : "Fejl ved indlæsning dialog skabelon: {error}",
    "No tags selected for deletion." : "Ingen mærker markeret til sletning.",
    "unknown text" : "ukendt tekst",
    "Hello world!" : "Hej verden!",
    "sunny" : "solrigt",
    "Hello {name}, the weather is {weather}" : "Hej {name}, vejret er {weather}",
    "Hello {name}" : "Hej {name}",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["hent %n fil","hent %n filer"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Opgraderingen er i gang, forlader du denne side kan det afbryde processen.",
    "Updating to {version}" : "Opdatering til {version}",
    "An error occurred." : "Der opstod en fejl.",
    "Please reload the page." : "Genindlæs venligst siden",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Opdateringen mislykkedes. For mere information <a href=\"{url}\"> se vores forumindlæg </a>, som dækker dette spørgsmål.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Opdateringen blev ikke udført korrekt. Rapporter venligst problemet til <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownClouds fællesskabet</a>.",
    "The update was successful. There were warnings." : "Opdateringen blev gennemført. Der fremkom advarsler.",
    "The update was successful. Redirecting you to ownCloud now." : "Opdateringen blev udført korrekt. Du bliver nu viderestillet til ownCloud.",
    "Searching other places" : "Søger på andre steder",
    "No search results in other folders" : "Søgning gav ingen resultater in andre mapper",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} søgeresultat fundet i andre mapper","{count} søgeresultater fundet i andre mapper"],
    "Personal" : "Personligt",
    "Users" : "Brugere",
    "Apps" : "Apps",
    "Admin" : "Admin",
    "Help" : "Hjælp",
    "Access forbidden" : "Adgang forbudt",
    "File not found" : "Filen blev ikke fundet",
    "The specified document has not been found on the server." : "Det angivne dokument blev ikke fundet på serveren.",
    "You can click here to return to %s." : "Du kan klikke her for at gå tilbage til %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej\n\nDette blot for at lade dig vide, at %s har delt %s med dig.\n\nSe det her: %s\n\n",
    "The share will expire on %s." : "Delingen vil udløbe om %s.",
    "Cheers!" : "Hav en fortsat god dag.",
    "Internal Server Error" : "Intern serverfejl",
    "The server encountered an internal error and was unable to complete your request." : "Servern stødte på en intern fejl og var ikke i stand til at fuldføre din forespørgsel.",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Fjernadresse: %s",
    "Request ID: %s" : "Forespørgsels-ID: %s",
    "Type: %s" : "Indtast: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Besked: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Linje: %s",
    "Trace" : "Sporing",
    "Imprint" : "Aftryk",
    "Create an <strong>admin account</strong>" : "Opret en <strong>administratorkonto</strong>",
    "Username" : "Brugernavn",
    "Storage & database" : "Lager & database",
    "Data folder" : "Datamappe",
    "Configure the database" : "Konfigurer databasen",
    "Only %s is available." : "Kun %s er tilgængelig.",
    "Install and activate additional PHP modules to choose other database types." : "Installér og aktivér yderligere PHP-moduler for at vælge andre databasetyper.",
    "For more details check out the documentation." : "For flere oplysninger, så henvises der til dokumentationen.",
    "Database user" : "Databasebruger",
    "Database password" : "Databasekodeord",
    "Database name" : "Navn på database",
    "Database tablespace" : "Database tabelplads",
    "Database host" : "Databasehost",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Angiv port-nummeret og host-navnet, tak (f.eks, localhost: 5432).",
    "Performance warning" : "Ydelses advarsel",
    "SQLite will be used as database." : "SQLite vil blive brugt som database.",
    "For larger installations we recommend to choose a different database backend." : "Til større installationer anbefaler vi at vælge en anden database-backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Brug af SQLite frarådes især når skrivebordsklienten anvendes til filsynkronisering.",
    "Finish setup" : "Afslut opsætning",
    "Finishing …" : "Færdigbehandler ...",
    "Need help?" : "Brug for hjælp?",
    "See the documentation" : "Se dokumentationen",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej med dig,<br><br>Dette er blot for at informere dig om, at %s har delt <strong>%s</strong> med dig.<br><a href=\"%s\">Se det her!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne applikation kræver JavaScript for at fungere korrekt. {linkstart}Slå venligst JavaScript til{linkend} og genindlæs siden. ",
    "Menu" : "Menu",
    "Log out" : "Log ud",
    "Search" : "Søg",
    "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
    "Please contact your administrator." : "Kontakt venligst din administrator",
    "An internal error occurred." : "Der opstod en intern fejl.",
    "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
    "Login" : "Login",
    "Username or email" : "Brugernavn eller email",
    "Wrong password. Reset it?" : "Forkert kodeord. Skal det nulstilles?",
    "Wrong password." : "Forkert kodeord.",
    "Stay logged in" : "Forbliv logget ind",
    "Alternative Logins" : "Alternative logins",
    "Use the following link to reset your password: {link}" : "Anvend følgende link til at nulstille din adgangskode: {link}",
    "Password changed successfully" : "Kodeord succesfuldt ændret.",
    "New password" : "Ny adgangskode",
    "New Password" : "Ny adgangskode",
    "Reset password" : "Nulstil kodeord",
    "This ownCloud instance is currently in single user mode." : "Denne ownCloud instans er lige nu i enkeltbruger tilstand.",
    "This means only administrators can use the instance." : "Det betyder at det kun er administrator, som kan benytte ownCloud.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren, hvis denne meddelelse fortsætter eller optrådte uventet.",
    "Thank you for your patience." : "Tak for din tålmodighed.",
    "Two-step verification" : "To-trins bekræftelse",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Øget sikkerhed er aktiveret for din konto. Bekræft venligst ved brug af den anden faktor.",
    "Cancel login" : "Annullér login",
    "Please authenticate using the selected factor." : "Bekræft venligst ved brug af den valgte faktor.",
    "An error occurred while verifying the token" : "Der opstod en fejl under kontrollen af token",
    "You are accessing the server from an untrusted domain." : "Du tilgår serveren fra et utroværdigt domæne",
    "App update required" : "Opdatering af app påkræves",
    "%s will be updated to version %s" : "%s vil blive opdateret til version %s",
    "These apps will be updated:" : "Følgende apps vil blive opdateret:",
    "The theme %s has been disabled." : "Temaet, %s, er blevet deaktiveret.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Sørg venligst for at sikre, at databasen, config-mappen og data-mappen er blevet sikkerhedskopieret inden vi fortsætter.",
    "Start update" : "Begynd opdatering",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For at undgå tidsudløb ved større installationer, så kan du i stedet køre følgende kommando fra din installationsmappe:",
    "Detailed logs" : "Detaljerede logge",
    "Update needed" : "Opdatering nødvendigt",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "For at få hjælp, se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> dokumentationen </a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instans befinder sig i vedligeholdelsestilstand for øjeblikket, hvilket kan tage et stykke tid.",
    "This page will refresh itself when the %s instance is available again." : "Denne side vil genopfriske sig selv, når %s-instancen er tilgængelig igen."
},
"nplurals=2; plural=(n != 1);");
